###########################################################################
#
# win32.mak -- Windows Makefile for runtime-src\src\oaiservr
#
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the
# University of Waikato, New Zealand.
#
# Copyright (C) 1999-2010  The New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################


GSDL_DIR = $(GSDLHOME)


# Programs compiled and their install directories
CGIBIN_DIR = "$(GSDL_DIR)\cgi-bin"
CGIBIN_PROGRAMS = oaiserver.cgi

# Program: oaiserver.cgi
OAISERVER_CGI_CPPFLAGS = \
	-I"$(GSDL_DIR)\common-src\src\lib" \
	-I"$(GSDL_DIR)\runtime-src\src\colservr" \
	-I"$(GSDL_DIR)\runtime-src\src\protocol" \
	-I"$(GSDL_DIR)\runtime-src\src\recpt"

# Objects for oaiserver.cgi
OAISERVER_CGI_OBJECTS = \
	"$(GSDL_DIR)\runtime-src\src\recpt\cgiargs.obj" \
	"$(GSDL_DIR)\runtime-src\src\recpt\cgiutils.obj" \
	"$(GSDL_DIR)\runtime-src\src\recpt\htmlutils.obj" \
	abstractlistaction.obj \
	dublincore.obj \
	qualified_dublincore.obj \
	identifyaction.obj \
	listidsaction.obj \
	listrecsaction.obj \
	listsetsaction.obj \
	metaformat.obj \
	metaformatsaction.obj \
	oaiaction.obj \
	oaiargs.obj \
	oaiconfig.obj \
	oaidispatcher.obj \
	oaimain.obj \
	oaitools.obj \
	recordaction.obj \
	resumptiontoken.obj \
	rfc1807.obj

OAISERVER_CGI_LDADD = \
	"$(GSDL_DIR)\runtime-src\src\protocol\gsdlprotocol.lib" \
	"$(GSDL_DIR)\runtime-src\src\colservr\gsdlcolservr.lib" \
	"$(GSDL_DIR)\common-src\src\lib\gsdllib.lib"


# Option: SQLite support
!IF $(USE_SQLITE)
OAISERVER_CGI_LDADD = $(OAISERVER_CGI_LDADD) "$(GSDL_DIR)\common-src\packages\sqlite\lib\sqlite3.lib"
!ENDIF


COMPILE = cl -nologo -c -EHsc -D__WIN32__ -DXML_STATIC -D_CRT_SECURE_NO_DEPRECATE $(OAISERVER_CGI_CPPFLAGS)
LINK = cl -nologo -Fe"$@"

.SUFFIXES:
.SUFFIXES: .cpp .obj

{}.cpp{}.obj:
	$(COMPILE) $<


oaiserver.cgi: $(OAISERVER_CGI_OBJECTS) $(OAISERVER_CGI_LDADD)
	$(LINK) $(OAISERVER_CGI_OBJECTS) $(OAISERVER_CGI_LDADD)

all: $(CGIBIN_PROGRAMS)

install: $(CGIBIN_PROGRAMS)
	copy $(CGIBIN_PROGRAMS) $(CGIBIN_DIR)

distclean:
	del *.obj $(CGIBIN_PROGRAMS) win32.mak

clean:
	del *.obj $(CGIBIN_PROGRAMS)
